==> gravitino-0.7.0-incubating-src.tar.gz: gravitino-0.7.0-incubating-src/iceberg/iceberg-rest-server/src/main/java/org/apache/gravitino/listener/api/event/IcebergCreateTablePreEvent.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */

package org.apache.gravitino.listener.api.event;

import org.apache.gravitino.NameIdentifier;
import org.apache.gravitino.annotation.DeveloperApi;
import org.apache.iceberg.rest.requests.CreateTableRequest;

/** Represent a pre event before creating Iceberg table. */
@DeveloperApi
public class IcebergCreateTablePreEvent extends IcebergTablePreEvent {
  private CreateTableRequest createTableRequest;

  public IcebergCreateTablePreEvent(
      String user, NameIdentifier resourceIdentifier, CreateTableRequest createTableRequest) {
    super(user, resourceIdentifier);
    this.createTableRequest = createTableRequest;
  }

  public CreateTableRequest createTableRequest() {
    return createTableRequest;
  }
}

==> gravitino-0.9.0-incubating-src.tar.gz: gravitino-0.9.0-incubating-src/iceberg/iceberg-rest-server/src/main/java/org/apache/gravitino/listener/api/event/IcebergCreateTablePreEvent.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */

package org.apache.gravitino.listener.api.event;

import org.apache.gravitino.NameIdentifier;
import org.apache.gravitino.annotation.DeveloperApi;
import org.apache.iceberg.rest.requests.CreateTableRequest;

/** Represent a pre event before creating Iceberg table. */
@DeveloperApi
public class IcebergCreateTablePreEvent extends IcebergTablePreEvent {
  private final CreateTableRequest createTableRequest;

  public IcebergCreateTablePreEvent(
      IcebergRequestContext icebergRequestContext,
      NameIdentifier resourceIdentifier,
      CreateTableRequest createTableRequest) {
    super(icebergRequestContext, resourceIdentifier);
    this.createTableRequest = createTableRequest;
  }

  @Override
  public OperationType operationType() {
    return OperationType.CREATE_TABLE;
  }

  public CreateTableRequest createTableRequest() {
    return createTableRequest;
  }
}
